SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';


-- -----------------------------------------------------
-- Table `Person`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Person` ;

CREATE  TABLE IF NOT EXISTS `Person` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `firstname` VARCHAR(64) NOT NULL ,
  `lastname` VARCHAR(128) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Role`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Role` ;

CREATE  TABLE IF NOT EXISTS `Role` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(64) NOT NULL ,
  `roleTableName` VARCHAR(128) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Business`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Business` ;

CREATE  TABLE IF NOT EXISTS `Business` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(128) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Role_Student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Role_Student` ;

CREATE  TABLE IF NOT EXISTS `Role_Student` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Role_Student_Person` (`person_identifier` ASC) ,
  CONSTRAINT `fk_Role_Student_Person`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Course`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Course` ;

CREATE  TABLE IF NOT EXISTS `Course` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `period_start` DATETIME NULL ,
  `period_end` DATETIME NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Role_Lecturer`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Role_Lecturer` ;

CREATE  TABLE IF NOT EXISTS `Role_Lecturer` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  `course_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Role_Lecturer_Person1` (`person_identifier` ASC) ,
  INDEX `fk_Role_Lecturer_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_Role_Lecturer_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Role_Lecturer_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Role_Studass`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Role_Studass` ;

CREATE  TABLE IF NOT EXISTS `Role_Studass` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  `course_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Role_Studass_Person1` (`person_identifier` ASC) ,
  INDEX `fk_Role_Studass_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_Role_Studass_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Role_Studass_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Role_GuestLecturer`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Role_GuestLecturer` ;

CREATE  TABLE IF NOT EXISTS `Role_GuestLecturer` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  `business_identifier` INT NOT NULL ,
  `course_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Role_GuestLecturer_Person1` (`person_identifier` ASC) ,
  INDEX `fk_Role_GuestLecturer_Business1` (`business_identifier` ASC) ,
  INDEX `fk_Role_GuestLecturer_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_Role_GuestLecturer_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Role_GuestLecturer_Business1`
    FOREIGN KEY (`business_identifier` )
    REFERENCES `Business` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Role_GuestLecturer_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `BasedOnCourse`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `BasedOnCourse` ;

CREATE  TABLE IF NOT EXISTS `BasedOnCourse` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `course_identifier` INT NOT NULL ,
  `isBasedOn_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_BasedOnCourse_Course1` (`course_identifier` ASC) ,
  INDEX `fk_BasedOnCourse_Course2` (`isBasedOn_identifier` ASC) ,
  CONSTRAINT `fk_BasedOnCourse_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_BasedOnCourse_Course2`
    FOREIGN KEY (`isBasedOn_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CoursePersonell`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CoursePersonell` ;

CREATE  TABLE IF NOT EXISTS `CoursePersonell` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `course_identifier` INT NOT NULL ,
  `role_identifier` INT NOT NULL ,
  `roleTable_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CoursePersonell_Course1` (`course_identifier` ASC) ,
  INDEX `fk_CoursePersonell_Role1` (`roleTable_identifier` ASC) ,
  CONSTRAINT `fk_CoursePersonell_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CoursePersonell_Role1`
    FOREIGN KEY (`roleTable_identifier` )
    REFERENCES `Role` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseResourceType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseResourceType` ;

CREATE  TABLE IF NOT EXISTS `CourseResourceType` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseResource`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseResource` ;

CREATE  TABLE IF NOT EXISTS `CourseResource` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `course_identifier` INT NOT NULL ,
  `resource_identifier` INT NOT NULL ,
  `requestedBy_person_identifier` INT NOT NULL ,
  `resourceType_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CourseResource_CourseResourceType1` (`resourceType_identifier` ASC) ,
  INDEX `fk_CourseResource_Course1` (`course_identifier` ASC) ,
  INDEX `fk_CourseResource_Person1` (`requestedBy_person_identifier` ASC) ,
  CONSTRAINT `fk_CourseResource_CourseResourceType1`
    FOREIGN KEY (`resourceType_identifier` )
    REFERENCES `CourseResourceType` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseResource_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseResource_Person1`
    FOREIGN KEY (`requestedBy_person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseParticipant`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseParticipant` ;

CREATE  TABLE IF NOT EXISTS `CourseParticipant` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  `course_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CourseParticipant_Person1` (`person_identifier` ASC) ,
  INDEX `fk_CourseParticipant_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_CourseParticipant_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseParticipant_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseEventType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseEventType` ;

CREATE  TABLE IF NOT EXISTS `CourseEventType` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(64) NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseEvent`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseEvent` ;

CREATE  TABLE IF NOT EXISTS `CourseEvent` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `course_identifier` INT NOT NULL ,
  `courseEventType_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CourseEvent_CourseEventType1` (`courseEventType_identifier` ASC) ,
  INDEX `fk_CourseEvent_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_CourseEvent_CourseEventType1`
    FOREIGN KEY (`courseEventType_identifier` )
    REFERENCES `CourseEventType` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseEvent_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseEventResource`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseEventResource` ;

CREATE  TABLE IF NOT EXISTS `CourseEventResource` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `courseResource_identifier` INT NOT NULL ,
  `courseEvent_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CourseEventResource_CourseResource1` (`courseResource_identifier` ASC) ,
  INDEX `fk_CourseEventResource_CourseEvent1` (`courseEvent_identifier` ASC) ,
  CONSTRAINT `fk_CourseEventResource_CourseResource1`
    FOREIGN KEY (`courseResource_identifier` )
    REFERENCES `CourseResource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseEventResource_CourseEvent1`
    FOREIGN KEY (`courseEvent_identifier` )
    REFERENCES `CourseEvent` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CourseEventParticipant`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CourseEventParticipant` ;

CREATE  TABLE IF NOT EXISTS `CourseEventParticipant` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `courseEvent_identifier` INT NOT NULL ,
  `courseParticipant_identifier` INT NOT NULL ,
  `reviewer_person_identifier` INT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CourseEventParticipant_CourseEvent1` (`courseEvent_identifier` ASC) ,
  INDEX `fk_CourseEventParticipant_CourseParticipant1` (`courseParticipant_identifier` ASC) ,
  INDEX `fk_CourseEventParticipant_Person1` (`reviewer_person_identifier` ASC) ,
  CONSTRAINT `fk_CourseEventParticipant_CourseEvent1`
    FOREIGN KEY (`courseEvent_identifier` )
    REFERENCES `CourseEvent` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseEventParticipant_CourseParticipant1`
    FOREIGN KEY (`courseParticipant_identifier` )
    REFERENCES `CourseParticipant` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CourseEventParticipant_Person1`
    FOREIGN KEY (`reviewer_person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `OwnerType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `OwnerType` ;

CREATE  TABLE IF NOT EXISTS `OwnerType` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` INT NOT NULL ,
  `ownerTableName` VARCHAR(128) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `ResourceType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ResourceType` ;

CREATE  TABLE IF NOT EXISTS `ResourceType` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(64) NOT NULL ,
  `resourceTableName` VARCHAR(128) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Resource`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Resource` ;

CREATE  TABLE IF NOT EXISTS `Resource` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resourceType_identifier` INT NOT NULL ,
  `owner_identifier` INT NOT NULL ,
  `ownerType_identifier` INT NOT NULL ,
  `publiser_person_identifier` INT NOT NULL ,
  `resourceTypeEntry_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Resource_OwnerType1` (`ownerType_identifier` ASC) ,
  INDEX `fk_Resource_ResourceType1` (`resourceType_identifier` ASC) ,
  INDEX `fk_Resource_Person1` (`owner_identifier` ASC) ,
  INDEX `fk_Resource_Person2` (`publiser_person_identifier` ASC) ,
  CONSTRAINT `fk_Resource_OwnerType1`
    FOREIGN KEY (`ownerType_identifier` )
    REFERENCES `OwnerType` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Resource_ResourceType1`
    FOREIGN KEY (`resourceType_identifier` )
    REFERENCES `ResourceType` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Resource_Person1`
    FOREIGN KEY (`owner_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Resource_Person2`
    FOREIGN KEY (`publiser_person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RType_Image`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RType_Image` ;

CREATE  TABLE IF NOT EXISTS `RType_Image` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Image_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_Image_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RType_Book`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RType_Book` ;

CREATE  TABLE IF NOT EXISTS `RType_Book` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Book_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_Book_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RType_Presentation`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RType_Presentation` ;

CREATE  TABLE IF NOT EXISTS `RType_Presentation` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Presentation_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_Presentation_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RType_Website`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RType_Website` ;

CREATE  TABLE IF NOT EXISTS `RType_Website` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Website_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_Website_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Institute`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Institute` ;

CREATE  TABLE IF NOT EXISTS `Institute` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(128) NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `InstituteCourse`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `InstituteCourse` ;

CREATE  TABLE IF NOT EXISTS `InstituteCourse` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `institute_identifier` INT NOT NULL ,
  `course_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_InstituteCourse_Institute1` (`institute_identifier` ASC) ,
  INDEX `fk_InstituteCourse_Course1` (`course_identifier` ASC) ,
  CONSTRAINT `fk_InstituteCourse_Institute1`
    FOREIGN KEY (`institute_identifier` )
    REFERENCES `Institute` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_InstituteCourse_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Message`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Message` ;

CREATE  TABLE IF NOT EXISTS `Message` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `course_identifier` INT NOT NULL ,
  `sender_coursePersonell_identifier` INT NOT NULL ,
  `message` TEXT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Message_Course1` (`course_identifier` ASC) ,
  INDEX `fk_Message_CoursePersonell1` (`sender_coursePersonell_identifier` ASC) ,
  CONSTRAINT `fk_Message_Course1`
    FOREIGN KEY (`course_identifier` )
    REFERENCES `Course` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Message_CoursePersonell1`
    FOREIGN KEY (`sender_coursePersonell_identifier` )
    REFERENCES `CoursePersonell` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `ExtendedField`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ExtendedField` ;

CREATE  TABLE IF NOT EXISTS `ExtendedField` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `extendedTableName` VARCHAR(128) NOT NULL ,
  `fieldName` VARCHAR(128) NOT NULL ,
  `fieldType` VARCHAR(64) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `ExtendedFieldValue`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ExtendedFieldValue` ;

CREATE  TABLE IF NOT EXISTS `ExtendedFieldValue` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `extendedField_identifier` INT NOT NULL ,
  `element_identifier` INT NOT NULL ,
  `fieldValue` TEXT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_ExtendedFieldValue_ExtendedField1` (`extendedField_identifier` ASC) ,
  CONSTRAINT `fk_ExtendedFieldValue_ExtendedField1`
    FOREIGN KEY (`extendedField_identifier` )
    REFERENCES `ExtendedField` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Tag`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Tag` ;

CREATE  TABLE IF NOT EXISTS `Tag` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(64) NOT NULL ,
  `description` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `TagElement`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `TagElement` ;

CREATE  TABLE IF NOT EXISTS `TagElement` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `tag_identifier` INT NOT NULL ,
  `elementTableName` VARCHAR(128) NOT NULL ,
  `element_identifier` INT NOT NULL ,
  `taggedBy_user_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_TagElement_Tag1` (`tag_identifier` ASC) ,
  CONSTRAINT `fk_TagElement_Tag1`
    FOREIGN KEY (`tag_identifier` )
    REFERENCES `Tag` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Note`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Note` ;

CREATE  TABLE IF NOT EXISTS `Note` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `person_identifier` INT NOT NULL ,
  `note` TEXT NOT NULL ,
  `resource_identifier` INT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_Note_Person1` (`person_identifier` ASC) ,
  CONSTRAINT `fk_Note_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `ElementNote`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ElementNote` ;

CREATE  TABLE IF NOT EXISTS `ElementNote` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `note_identifier` INT NOT NULL ,
  `elementTableName` VARCHAR(128) NOT NULL ,
  `element_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_ElementNote_Note1` (`note_identifier` ASC) ,
  CONSTRAINT `fk_ElementNote_Note1`
    FOREIGN KEY (`note_identifier` )
    REFERENCES `Note` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `User`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `User` ;

CREATE  TABLE IF NOT EXISTS `User` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `token` VARCHAR(255) NOT NULL ,
  `person_identifier` INT NULL DEFAULT NULL,
  `institute_identifier` INT NULL DEFAULT NULL,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_User_Person1` (`person_identifier` ASC) ,
  INDEX `fk_User_Institute1` (`institute_identifier` ASC) ,
  CONSTRAINT `fk_User_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_User_Institute1`
    FOREIGN KEY (`institute_identifier` )
    REFERENCES `Institute` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `AccessRole`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `AccessRole` ;

CREATE  TABLE IF NOT EXISTS `AccessRole` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(64) NOT NULL ,
  `description` VARCHAR(255) NULL ,
  PRIMARY KEY (`identifier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RoleInstance`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RoleInstance` ;

CREATE  TABLE IF NOT EXISTS `RoleInstance` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `accessRole_identifier` INT NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_RoleInstance_AccessRole1` (`accessRole_identifier` ASC) ,
  CONSTRAINT `fk_RoleInstance_AccessRole1`
    FOREIGN KEY (`accessRole_identifier` )
    REFERENCES `AccessRole` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RoleOption`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RoleOption` ;

CREATE  TABLE IF NOT EXISTS `RoleOption` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `accessRole_identifier` INT NOT NULL ,
  `optionName` VARCHAR(64) NOT NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_RoleOption_AccessRole1` (`accessRole_identifier` ASC) ,
  CONSTRAINT `fk_RoleOption_AccessRole1`
    FOREIGN KEY (`accessRole_identifier` )
    REFERENCES `AccessRole` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RoleOptionValue`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RoleOptionValue` ;

CREATE  TABLE IF NOT EXISTS `RoleOptionValue` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `roleOption_identifier` INT NOT NULL ,
  `roleInstance_identifier` INT NOT NULL ,
  `optionValue` VARCHAR(128) NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_RoleOptionValue_RoleOption1` (`roleOption_identifier` ASC) ,
  INDEX `fk_RoleOptionValue_RoleInstance1` (`roleInstance_identifier` ASC) ,
  CONSTRAINT `fk_RoleOptionValue_RoleOption1`
    FOREIGN KEY (`roleOption_identifier` )
    REFERENCES `RoleOption` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_RoleOptionValue_RoleInstance1`
    FOREIGN KEY (`roleInstance_identifier` )
    REFERENCES `RoleInstance` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `UserRoleInstance`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `UserRoleInstance` ;

CREATE  TABLE IF NOT EXISTS `UserRoleInstance` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `user_identifier` INT NOT NULL ,
  `roleInstance_identifier` INT NOT NULL ,
  `assignedDateTime` DATETIME NOT NULL ,
  `expireDateTime` DATETIME NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_UserRoleInstance_User1` (`user_identifier` ASC) ,
  INDEX `fk_UserRoleInstance_RoleInstance1` (`roleInstance_identifier` ASC) ,
  CONSTRAINT `fk_UserRoleInstance_User1`
    FOREIGN KEY (`user_identifier` )
    REFERENCES `User` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_UserRoleInstance_RoleInstance1`
    FOREIGN KEY (`roleInstance_identifier` )
    REFERENCES `RoleInstance` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `ResourceRight`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ResourceRight` ;

CREATE  TABLE IF NOT EXISTS `ResourceRight` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  `user_identifier` INT NOT NULL ,
  `view` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `modify` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `delete` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `open` TINYINT(1) NOT NULL DEFAULT FALSE ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_ResourceRight_User1` (`user_identifier` ASC) ,
  INDEX `fk_ResourceRight_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_ResourceRight_User1`
    FOREIGN KEY (`user_identifier` )
    REFERENCES `User` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ResourceRight_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `RoleResourceRight`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `RoleResourceRight` ;

CREATE  TABLE IF NOT EXISTS `RoleResourceRight` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `resource_identifier` INT NOT NULL ,
  `roleInstance_identifier` INT NOT NULL ,
  `view` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `modify` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `delete` TINYINT(1) NOT NULL DEFAULT FALSE ,
  `open` TINYINT(1) NOT NULL DEFAULT FALSE ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_RoleResourceRight_Resource1` (`resource_identifier` ASC) ,
  INDEX `fk_RoleResourceRight_RoleInstance1` (`roleInstance_identifier` ASC) ,
  CONSTRAINT `fk_RoleResourceRight_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_RoleResourceRight_RoleInstance1`
    FOREIGN KEY (`roleInstance_identifier` )
    REFERENCES `RoleInstance` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `AccessCriterion`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `AccessCriterion` ;

CREATE  TABLE IF NOT EXISTS `AccessCriterion` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `roleInstance_identifier` INT NOT NULL ,
  `resource_identifier` INT NOT NULL ,
  `startTime` DATETIME NULL ,
  `endTime` DATETIME NULL ,
  `view` TINYINT(1) NULL ,
  `modify` TINYINT(1) NULL ,
  `delete` TINYINT(1) NULL ,
  `open` TINYINT(1) NULL ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_AccessCriterion_RoleInstance1` (`roleInstance_identifier` ASC) ,
  INDEX `fk_AccessCriterion_Resource1` (`resource_identifier` ASC) ,
  CONSTRAINT `fk_AccessCriterion_RoleInstance1`
    FOREIGN KEY (`roleInstance_identifier` )
    REFERENCES `RoleInstance` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_AccessCriterion_Resource1`
    FOREIGN KEY (`resource_identifier` )
    REFERENCES `Resource` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `CoursePersonellInstance`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `CoursePersonellInstance` ;

CREATE  TABLE IF NOT EXISTS `CoursePersonellInstance` (
  `identifier` INT NOT NULL AUTO_INCREMENT ,
  `personell_identifier` INT NOT NULL ,
  `person_identifier` INT NOT NULL ,
  `fromDate` DATE NOT NULL ,
  `toDate` DATE NOT NULL ,
  `planned` TINYINT(1) NOT NULL DEFAULT 0 ,
  `actual` TINYINT(1) NOT NULL DEFAULT 0 ,
  PRIMARY KEY (`identifier`) ,
  INDEX `fk_CoursePersonellInstance_CoursePersonell1` (`personell_identifier` ASC) ,
  INDEX `fk_CoursePersonellInstance_Person1` (`person_identifier` ASC) ,
  CONSTRAINT `fk_CoursePersonellInstance_CoursePersonell1`
    FOREIGN KEY (`personell_identifier` )
    REFERENCES `CoursePersonell` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_CoursePersonellInstance_Person1`
    FOREIGN KEY (`person_identifier` )
    REFERENCES `Person` (`identifier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;





/*Create entries for existing Person-roles and Resource-types*/
INSERT INTO Role (name, roleTableName) VALUES ("Student", "Role_Student");
INSERT INTO Role (name, roleTableName) VALUES ("Guest lecturer", "Role_GuestLecturer");
INSERT INTO Role (name, roleTableName) VALUES ("Lecturer", "Role_Lecturer");
INSERT INTO Role (name, roleTableName) VALUES ("Studass", "Role_Studass");

INSERT INTO ResourceType (name, resourceTableName) VALUES ("Image", "RType_Image");
INSERT INTO ResourceType (name, resourceTableName) VALUES ("Book", "RType_Book");
INSERT INTO ResourceType (name, resourceTableName) VALUES ("Presentation", "RType_Presentation");
INSERT INTO ResourceType (name, resourceTableName) VALUES ("Website", "RType_Website");






/*Create default root account with root priveliges.*/
/*Create a user*/
INSERT INTO User (token) VALUES ("ab3e3013d5a77039d7ec653b6aed73e2a94f0b8a874ad3fb5f8cae275c981c1a2e51a889e952c334ce0e26ff5b985521da2d11d382e4f1136cf27dbe835f86d1");

/*Create a root role (Full access to the system and all functions. No options needed for this one.)*/
INSERT INTO AccessRole (name, description) VALUES ("root", "Admin role (full access)");

/*Create an instance of that role so it can be linked*/
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="root";

/*Create a connection between the created user and the role instance*/
INSERT INTO UserRoleInstance (user_identifier, roleInstance_identifier, assignedDateTime, expireDateTime)
SELECT u.identifier, ri.identifier, NOW(), NULL FROM User as u, RoleInstance as ri, AccessRole as ar
WHERE u.token="ab3e3013d5a77039d7ec653b6aed73e2a94f0b8a874ad3fb5f8cae275c981c1a2e51a889e952c334ce0e26ff5b985521da2d11d382e4f1136cf27dbe835f86d1"
AND ar.name="root"
AND ri.accessRole_identifier=ar.identifier;



/*Create some basic user roles for managing the system*/
/*Course administrator (allowed to administer courses)*/
INSERT INTO AccessRole (name, description) VALUES ("courseAdmin", "Allows administration of all courses");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="courseAdmin";

/*Person administrator*/
INSERT INTO AccessRole (name, description) VALUES ("personAdmin", "Allows administration of all persons in the system");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="personAdmin";

/*User administrator*/
INSERT INTO AccessRole (name, description) VALUES ("userAdmin", "Allows administration of all users except root accounts");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="userAdmin";

/*View all (good for backup operations and such)*/
INSERT INTO AccessRole (name, description) VALUES ("viewAll", "Allows the user to view any data, but not change it");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="viewAll";

/*Course manager (not instanced)*/
INSERT INTO AccessRole (name, description) VALUES ("courseManager", "Allows administration of a single course");
INSERT INTO RoleOption (accessRole_identifier, optionName) SELECT identifier, "courseIdentifier" FROM AccessRole WHERE name="courseManager";

/*Resource administrator*/
INSERT INTO AccessRole (name, description) VALUES ("resourceAdmin", "Allows administration of all resources");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="resourceAdmin";

/*Manage tags*/
INSERT INTO AccessRole (name, description) VALUES ("tagsAdmin", "Allows the creation of tags for any object");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="createTag";

/*Tag an item (not create)*/
INSERT INTO AccessRole (name, description) VALUES ("doTag", "Allows the user to tag an item with an existing tag");
INSERT INTO RoleInstance (accessRole_identifier) SELECT identifier FROM AccessRole WHERE name="doTag";