package clientCommunicator.rmi;

import java.net.MalformedURLException;
import java.rmi.AlreadyBoundException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import core.Core;
import core.CoreInterface;
import clientCommunicator.ClientCommunicatorManager;

public class RMICommunicatorManager implements ClientCommunicatorManager {
	
	private static final String RMIUrl = "rmi://127.0.0.1/MasterRMIInterface";
	protected static CoreInterface coreInt;
	
	private boolean isStarted = false;
	
	@Override
	public void start() {
		if ( isStarted ) return;
		coreInt = Core.getCore();
		coreInt.getPluginLogger().info("RMICommunicator v0.2: Starting...");
		
		isStarted = true;
		
		coreInt.getPluginLogger().warning("RMICommunicator: Setting new SecurityManager that grants all permissions.");
		System.setSecurityManager(new FullAccessSecurityManager());
		
		try {
			RMIServicesInterface rmiClass = new RMICommunicator();
			coreInt.getPluginLogger().fine("RMICommunicator: Registering with RMI repository.");
			Naming.bind(RMIUrl, rmiClass);
			coreInt.getPluginLogger().fine("RMICommunicator: Registeration with RMI repository complete.");
		} catch (MalformedURLException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not register with repository. Malformed URL: "+RMIUrl);
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
			this.stop();
			return;
		} catch (RemoteException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not register with repository. RemoteException");
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
			this.stop();
			return;
		} catch (AlreadyBoundException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not register with repository. AlreadyBoundException");
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
			this.stop();
			return;
		}
		
		coreInt.getPluginLogger().info("RMICommunicator: Started!");
	}

	@Override
	public void stop() {
		if ( !isStarted ) return;
		coreInt.getPluginLogger().info("RMICommunicator: Stopping...");
		
		try {
			Naming.unbind(RMIUrl);
		} catch (RemoteException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not unregister with repository. RemoteException");
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
		} catch (MalformedURLException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not unregister with repository. Malformed URL: "+RMIUrl);
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
		} catch (NotBoundException e) {
			coreInt.getPluginLogger().warning("RMICommunicator: Could not unregister with repository. NotBoundException");
			coreInt.getPluginLogger().warning(Core.stackTraceToString(e));
		}
		
		isStarted = false;
		coreInt.getPluginLogger().info("RMICommunicator: Stopped!");
	}

}
