package clientCommunicator.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;
import java.util.HashMap;

/**
 * Defines what services are provided for clients connecting through RMI connections.
 * 
 * @author Thomas Rudfoss
 *
 */
public interface RMIServicesInterface extends Remote {

	/**
	 * Send a request to the server with an XML formatted document defining the request.
	 * 
	 * @param xmlDoc The xml document containing data about the operation
	 * @param token The token identifying the user.
	 * @return
	 * @throws RemoteException
	 */
	public String xmlRequest(String xmlDoc, String token) throws RemoteException;
	
	/**
	 * Send a request to the server with a JSON formatted document defining the request.
	 * 
	 * @param jsonData The json data string containing the operation
	 * @param token The token identifying the user.
	 * @return
	 * @throws RemoteException
	 */
	public String jsonRequest(String jsonData, String token) throws RemoteException;
	
	
	public boolean verifyToken(String token) throws RemoteException;
	
	/**
	 * Send an administrative command to the system. Only available if you are registered with the root role in the system.
	 * The token parameter should be an identifier that is used to verify your identity and rights.
	 * 
	 * @param command The command to execute
	 * @param token The identifier for you
	 * @return The given RMI command with proper status fields filled in. Use it to verify that the command has been properly executed. 
	 * @throws RemoteException
	 */
	public int sendAdminCommand(String cmd, HashMap<String, String> options, String token) throws RemoteException;
	
	/**
	 * Returns a string array of all commands that can be executed on the server.
	 * 
	 * @param token
	 * @return
	 * @throws RemoteException
	 */
	public String[] getAdminCommands(String token) throws RemoteException;
	
	/**
	 * Used for testing to ensure a connection is established. Returns the given message.
	 * 
	 * @param msg The message that will be returned.
	 * @return
	 */
	public String ping(String msg) throws RemoteException;
}
