package core;

import java.util.Scanner;

import core.userData.UserData;
import core.userData.exceptions.DatabaseConnectionException;
import core.userData.exceptions.TokenNotFoundException;

/**
 * Simple class that allows administration from the console.
 * 
 * @author Thomas Rudfoss
 *
 */
public class ConsoleAdmin implements Runnable{
	
	private boolean run = true;

	@Override
	public void run() {
		System.out.println("");
		System.out.println("Console administration active. Waiting for command. Type help(enter) for list of commands.");
		String command = null;
		while ( this.run ){
			Scanner sc = new Scanner(System.in);
			System.out.print("> ");
			command = sc.nextLine();
			
			this.performCommand(command);
		}
	}
	
	private void performCommand(String cmd){
		if ( cmd.equalsIgnoreCase("exit") ){
			this.run = false;
			Core.getCoreFromCore().shutdown();
		} else if ( cmd.equalsIgnoreCase("config") ){
			System.out.println("Configuration");
			System.out.println(Core.config);
		} else if ( cmd.equalsIgnoreCase("state") ){
			Core.jobManager.printState();
		} else if ( cmd.equalsIgnoreCase("emptyJobQueue") ){
			Core.jobManager.clearQueuedJobs();
			System.out.println("Job queue has been emptied!");
		} else if ( cmd.equalsIgnoreCase("makeUserObject") ){
			String token = "0e0c9317a24f2a018e788762457b4b7c83ef9e652ac3666ae137f94f5765dfd50e1ad41c324c8a248d29fa6ea85572d532284049c7bce56545ee4a469be16c38";
			System.out.println("Making user object for root user with token:");
			System.out.println(token);
			System.out.println("");
			try {
				UserData ud = UserData.constructFromToken(token);
				System.out.println(ud);
			} catch (DatabaseConnectionException e) {
				System.out.println("Failed with DatabaseConnectionException:");
				e.printStackTrace();
			} catch (TokenNotFoundException e) {
				System.out.println("Token not found!");
			}
		} else if ( cmd.equalsIgnoreCase("help") ){
			System.out.println("List of commands:");
			System.out.println("config - Show configuration parameters");
			System.out.println("emptyJobQueue - Empty the queue of waiting jobs (safe).");
			System.out.println("makeUserObject - Make a UserData object for a user for testing.");
			System.out.println("state - Shows the state of the system");
			System.out.println("exit - Shut down the core");
			System.out.println("help - Show this help");
		} else {
			System.err.println("Unknown command "+cmd);
		}
		System.out.println("");
	}

}
