package jobExecutors;

import org.json.JSONException;
import org.json.JSONObject;

import core.Core;
import core.Job;
import core.ResponseTemplateTypes;
import core.userData.UserData;
import core.userData.exceptions.DatabaseConnectionException;
import core.userData.exceptions.TokenNotFoundException;

public class BlankJobExecutor implements JobExecutorInterface {
	
	public static String[] jobsICanDo(){
		return new String[]{"blankJob", "testingWithDelay", "jsonTest", "xmlTest"};
	}

	@Override
	public synchronized void doJob(Job job) {
		try {
			UserData.constructFromToken(job.getToken());
		} catch (DatabaseConnectionException e1) {
			job.state = Job.STATE_FAILED;
			job.statusCode = 100;
			job.statusMessage = "No database connection!";
			job.result = ResponseTemplateTypes.SERVER_ERROR.json;
			return;
		} catch (TokenNotFoundException e1) {
			job.state = Job.STATE_FAILED;
			job.statusCode = 20;
			job.statusMessage = "No user with that token";
			job.result = ResponseTemplateTypes.UKNOWN_USER.json;
			return;
		}
		
		if ( job.getJobTask().equalsIgnoreCase("blankJob") || job.getJobTask().equalsIgnoreCase("testingWithDelay") ){
			Core.getCore().getPluginLogger().fine("BlankJobExecutor going to work!");
			job.state = Job.STATE_RUNNING;
			System.out.println("BlankJobExecutor: executing job");
			
			long sleepFor = 3000;
			if ( job.request.has("sleepFor") ){
				try {
					sleepFor = job.request.getLong("sleepFor");
				} catch (JSONException e) {
					sleepFor = 3000;
					e.printStackTrace();
				}
			}
			try {
				System.out.println("BlankJobExecutor: Sleeping for "+sleepFor+" ms");
				this.wait(3000);
			} catch (InterruptedException e) {
				job.state = Job.STATE_FAILED;
				job.statusCode = 100;
				job.statusMessage = "Worker interrupted";
				job.result = ResponseTemplateTypes.SERVER_ERROR.json;
				
				Core.getCore().getPluginLogger().info("BlankJobExecutor instance has been interrupted");
				System.out.println("BlankJobExecutor: job interrupted");
				return;
			}
			
			System.out.println("BlankJobExecutor: job executed");
			job.result = "This is a result";
			job.state = Job.STATE_RESULT_SET;
		} else if ( job.getJobTask().equalsIgnoreCase("jsonTest") || job.getJobTask().equalsIgnoreCase("xmlTest") ){
			System.out.println("Recieved JSON/XML request");
			System.out.println(job.request.toString());
			try {
				job.internalResult = new JSONObject("{\"hello\":\"world\"}");
			} catch (JSONException e) {
				e.printStackTrace();
				job.internalResult = null;
				job.state = Job.STATE_FAILED;
				job.statusCode = 100;
				job.statusMessage = "Failed due to exception!";

				job.result = ResponseTemplateTypes.SERVER_ERROR.json;
				return;
			}
			
			job.state = Job.STATE_RESULT_SET;
		}
	}

}
