package jobExecutors;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.logging.Level;

import org.json.JSONException;
import org.json.JSONObject;

import core.Core;
import core.Job;
import core.errorHelper.ErrorObject;

/**
 * Testing complete: OK
 * 
 * @author Thomas Rudfoss
 *
 */
public class ClassJobExecutor implements JobExecutorInterface {

	public static final int RETURNCODE_NO_RESULT = 10;
	public static final int RETURNCODE_ELEMENT_EXISTS = 20;
	
	private static String[] jobsICanDoList = new String[]{"createCourse"};

	public static String[] jobsICanDo(){
		return jobsICanDoList.clone();
	}
	
	private Job theJob = null;
	private JSONObject data = null;
	
	@Override
	public void doJob(Job job) {
		log("Going to work!");
		
		theJob = job;
		try {
			theJob.request = theJob.request.getJSONObject("request");
		} catch (JSONException e1) {
			ErrorObject.getErrorForCode(ErrorObject.CODE_INVALID_REQUEST_FORMAT, theJob);
			log(Level.FINE, "Could not grab request node.");
			logStackTrace(Level.FINE, e1);
			return;
		}
		
		if ( !hasProperRights() ){
			ErrorObject.getErrorForCode(ErrorObject.CODE_ACCESS_DENIED, theJob);
			return;
		}
		
		try {
			theJob.internalResult = new JSONObject("{\"response\":{\"responsespec\":{\"status\":0,\"statusmessage\":\"OK\"}}}");
		} catch (JSONException e) {
			ErrorObject.getErrorForCode(ErrorObject.CODE_SERVER_ERROR, theJob);
			log(Level.SEVERE, "Could not initialize result object!");
			logStackTrace(Level.SEVERE, e);
			return;
		}
		
		try {
			if ( theJob.getJobTask().equalsIgnoreCase(jobsICanDoList[0]) ){
				data = theJob.request.getJSONObject("data");
				this.createCourse();
			}
			
			theJob.state = Job.STATE_RESULT_SET;
		} catch ( JSONException e ){
			ErrorObject.getErrorForCode(ErrorObject.CODE_MISSING_DATA, theJob);
			log("Missing data for the request.");
			logStackTrace(e);
		} catch (SQLException e) {
			ErrorObject.getErrorForCode(ErrorObject.CODE_SERVER_ERROR, theJob);
			log(Level.WARNING, "SQL Exception occured when inserting into person.");
			logStackTrace(Level.WARNING, e);
		}
		
		log("Finished work!");
	}
	
	private void createCourse() throws SQLException, JSONException{
		PreparedStatement stmt = theJob.dbConnection.newPreparedStatement("INSERT INTO Course (period_start, period_end) VALUES (?, ?)");
		stmt.setString(1, data.getString("period_start"));
		stmt.setString(2, data.getString("period_end"));
		stmt.execute();
	}

	private boolean hasProperRights(){
		if ( theJob.userData.isAdmin() ) return true; //Admins always have access
		
		if ( theJob.userData.hasRole("courseAdmin") ) return true;
		
		return false;
	}
	
	private void log(Level level, String msg){
		Core.getCore().getPluginLogger().log(level, "ClassJobExecutor: "+msg);
	}
	
	private void logStackTrace(Level level, Exception e){
		log(level, Core.stackTraceToString(e));
	}
	
	private void logStackTrace(Exception e){
		log(Level.FINER, Core.stackTraceToString(e));
	}
	
	private void log(String msg){
		this.log(Level.FINER, msg);
	}
	
}
