package jobExecutors;

import core.Job;

/**
 * Assumptions a job executor can make:
 * - I am running alone in this thread
 * - When I am done all I have to do is return from the doJob method. The core will take care of the rest.
 * - Database connections are established for me (see the Job object)
 * - The identity of the user has been verified or else I will not get to execute
 * - All the details I need for the job is inside the job object (job.details) and is always a properly formatted JSON object where the root node is "request".
 * - I do not have to worry about the format of the final result.
 * - I have to store my result in job.internalResult as a valid JSONObject.
 * - I cannot set job.internalResult as null
 * - I dont even have to close the database statements I use because the JobManager does this for me when I'm done. 
 * 
 * 
 * 
 * A JobExecutor must declare a static method jobsICanDo that returns a string array of jobs it can do.
 * Example:
 * public static String[] jobsICanDo(){
		return new String[]{"blankJob", "testingWithDelay", "jsonTest", "xmlTest"};
	}
	This is used by the core to redirect jobs to their proper executors and is therefore required.
	A JobExecutor without this method will not be loaded.
 * 
 * Tasks a JobExecutor must do
 * 1. Check if the user has the proper privileges to run
 * 2. Execute the job
 * 3. Set a result of some kind in internalResult on success
 * 4. Set Job.state = Job.STATE_RESULT_SET when successfully completed
 * 
 * If error:
 * Set job.state to proper state
 * Set job.statusCode to proper code (see report)
 * Set job.statusMessage to something readable
 * Log the error to the plugin logger
 * Set job.result to the proper JSON response from ResponseTemplateTypes 
 * 
 * @author Thomas Rudfoss
 *
 */
public interface JobExecutorInterface {

	public void doJob(Job job);
	
}
