package resultTranslators;

import core.Job;

/**
 * This interface must be implemented by all translator plugins for proper use with the core.
 * 
 * A ResultTranslator works like an interpreter and translates the result of a job from one format to another.
 * Note that by default the job contains the result as a resultSet and all translators should therefore be able
 * to understand this format.
 * 
 * The name of the default format of data comming directly from the job executor is:
 * JSONObject
 * 
 * @author Thomas Rudfoss
 *
 */
public interface ResultTranslatorInterface {

	/**
	 * Translate the result of the given job from JSONObject (internalResult) to toFormat
	 * 
	 * @param job The job with the result that is to be translated
	 * @param toFormat The destination format for the job result 
	 */
	public void translateJob(Job job, String toFormat);
	
}
